# Generated by Django 4.2.20 on 2025-05-01 22:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('headless_waf_builder', '0004_adjusting_thanks_page_content_richtext_features'),
    ]

    operations = [
        migrations.AddField(
            model_name='emailformpage',
            name='use_google_recaptcha',
            field=models.BooleanField(default=False, help_text='Please tick this option to enable Google Recaptcha'),
        ),
        migrations.AddField(
            model_name='formpage',
            name='use_google_recaptcha',
            field=models.BooleanField(default=False, help_text='Please tick this option to enable Google Recaptcha'),
        ),
    ]
