# Generated by Django 4.2.20 on 2025-04-23 04:15

from django.db import migrations
import wagtail.fields


class Migration(migrations.Migration):

    dependencies = [
        ('headless_waf_builder', '0003_switch_streamfield_to_use_json_field'),
    ]

    operations = [
        migrations.AlterField(
            model_name='emailformpage',
            name='form',
            field=wagtail.fields.StreamField([('singleline', 14), ('email', 15), ('html', 18), ('dropdown', 22), ('radio', 24), ('checkboxes', 27), ('checkbox', 29), ('multiselect', 30), ('multiline', 31), ('url', 32), ('hidden', 34), ('number', 35)], block_lookup={0: ('wagtail.blocks.CharBlock', (), {'help_text': 'The label of the form field.', 'max_length': 255, 'required': True}), 1: ('wagtail.blocks.BooleanBlock', (), {'default': False, 'help_text': 'Tick this box to make this a required field.', 'required': False}), 2: ('wagtail.blocks.IntegerBlock', (), {'help_text': 'Set a maximum length for this field. e.g. 100', 'required': False}), 3: ('wagtail.blocks.CharBlock', (), {'help_text': 'Set a default value for this field.', 'max_length': 255, 'required': False}), 4: ('wagtail.blocks.CharBlock', (), {'help_text': 'Text to assist the user in populating this field.', 'max_length': 255, 'required': False}), 5: ('wagtail.blocks.ChoiceBlock', [], {'choices': [('show', 'Show'), ('hide', 'Hide')], 'help_text': 'What conditional action would you like to perform on this field?'}), 6: ('wagtail.blocks.CharBlock', (), {'help_text': 'The name of a field in the form', 'max_length': 255, 'required': True}), 7: ('wagtail.blocks.ChoiceBlock', [], {'choices': [('is', 'Is equal to'), ('is_not', 'Is not equal to'), ('greater_than', 'Greater than'), ('greater_than_equal', 'Greater than or equal to'), ('less_than', 'Less than'), ('less_than_equal', 'Less than or equal to'), ('contains', 'Contains'), ('starts-with', 'Starts with'), ('ends-with', 'Ends with')]}), 8: ('wagtail.blocks.CharBlock', (), {'help_text': '', 'max_length': 255, 'required': True}), 9: ('wagtail.blocks.StructBlock', [[('field_name', 6), ('rule', 7), ('value', 8)]], {}), 10: ('wagtail.blocks.ChoiceBlock', [], {'choices': [('is_blank', 'Is blank'), ('is_not_blank', 'Is not blank')]}), 11: ('wagtail.blocks.StructBlock', [[('field_name', 6), ('rule', 10)]], {}), 12: ('wagtail.blocks.StreamBlock', [[('condition', 9), ('blank_condition', 11)]], {'required': False}), 13: ('wagtail.blocks.StructBlock', [[('action', 5), ('conditions', 12)]], {'help_text': 'Add conditional rules to show or hide fields depending on the value of other fields in the form.', 'required': False}), 14: ('wagtail.blocks.StructBlock', [[('label', 0), ('required', 1), ('max_length', 2), ('default_value', 3), ('help_text', 4), ('rules', 13)]], {'label': 'Basic field'}), 15: ('wagtail.blocks.StructBlock', [[('label', 0), ('required', 1), ('max_length', 2), ('default_value', 3), ('help_text', 4), ('rules', 13)]], {'label': 'Email field'}), 16: ('wagtail.blocks.CharBlock', (), {'help_text': 'A unique reference for this html block', 'label': 'Unique reference name', 'max_length': 255, 'required': True}), 17: ('wagtail.blocks.RichTextBlock', (), {'features': ['bold', 'italic', 'h2', 'h3', 'h4', 'h5', 'ol', 'ul', 'link'], 'required': True}), 18: ('wagtail.blocks.StructBlock', [[('label', 16), ('html', 17), ('rules', 13)]], {'label': 'HTML'}), 19: ('wagtail.blocks.TextBlock', (), {'icon': 'extraicons--heading-icon', 'required': True}), 20: ('wagtail.blocks.ListBlock', (19,), {}), 21: ('wagtail.blocks.CharBlock', (), {'max_length': 255, 'required': False}), 22: ('wagtail.blocks.StructBlock', [[('label', 0), ('required', 1), ('choices', 20), ('empty_label', 21), ('default_value', 3), ('help_text', 4), ('rules', 13)]], {'label': 'Dropdown field'}), 23: ('wagtail.blocks.BooleanBlock', (), {'help_text': 'Display these items side by side?', 'required': False}), 24: ('wagtail.blocks.StructBlock', [[('label', 0), ('required', 1), ('choices', 20), ('default_value', 3), ('help_text', 4), ('display_side_by_side', 23), ('rules', 13)]], {'label': 'Radio field'}), 25: ('wagtail.blocks.TextBlock', (), {'help_text': 'Enter a value that matches a checkbox choice above to have it ticked by default.', 'icon': 'extraicons--heading-icon', 'required': False}), 26: ('wagtail.blocks.ListBlock', (25,), {}), 27: ('wagtail.blocks.StructBlock', [[('label', 0), ('required', 1), ('choices', 20), ('default_value', 26), ('help_text', 4), ('display_side_by_side', 23), ('rules', 13)]], {'label': 'Checkboxes field'}), 28: ('wagtail.blocks.BooleanBlock', (), {'default': False, 'help_text': 'Do you want the checkbox label to display? If not you should populate help_text.', 'required': False}), 29: ('wagtail.blocks.StructBlock', [[('label', 0), ('required', 1), ('display_checkbox_label', 28), ('help_text', 21), ('rules', 13)]], {'label': 'Checkbox field'}), 30: ('wagtail.blocks.StructBlock', [[('label', 0), ('required', 1), ('choices', 20), ('default_value', 3), ('help_text', 4), ('rules', 13)]], {'label': 'Multiselect field'}), 31: ('wagtail.blocks.StructBlock', [[('label', 0), ('required', 1), ('default_value', 3), ('help_text', 4), ('rules', 13)]], {'label': 'Multiline field'}), 32: ('wagtail.blocks.StructBlock', [[('label', 0), ('required', 1), ('max_length', 2), ('default_value', 3), ('help_text', 4), ('rules', 13)]], {'label': 'URL field'}), 33: ('wagtail.blocks.CharBlock', (), {'help_text': 'The value to go into the hidden field.', 'label': 'Value', 'max_length': 255, 'required': True}), 34: ('wagtail.blocks.StructBlock', [[('label', 0), ('default_value', 33)]], {'label': 'Hidden field'}), 35: ('wagtail.blocks.StructBlock', [[('label', 0), ('required', 1), ('default_value', 3), ('help_text', 4), ('rules', 13)]], {'label': 'Number field'})}, default=None, help_text='Add fields to the form', null=True),
        ),
        migrations.AlterField(
            model_name='formpage',
            name='form',
            field=wagtail.fields.StreamField([('singleline', 14), ('email', 15), ('html', 18), ('dropdown', 22), ('radio', 24), ('checkboxes', 27), ('checkbox', 29), ('multiselect', 30), ('multiline', 31), ('url', 32), ('hidden', 34), ('number', 35)], block_lookup={0: ('wagtail.blocks.CharBlock', (), {'help_text': 'The label of the form field.', 'max_length': 255, 'required': True}), 1: ('wagtail.blocks.BooleanBlock', (), {'default': False, 'help_text': 'Tick this box to make this a required field.', 'required': False}), 2: ('wagtail.blocks.IntegerBlock', (), {'help_text': 'Set a maximum length for this field. e.g. 100', 'required': False}), 3: ('wagtail.blocks.CharBlock', (), {'help_text': 'Set a default value for this field.', 'max_length': 255, 'required': False}), 4: ('wagtail.blocks.CharBlock', (), {'help_text': 'Text to assist the user in populating this field.', 'max_length': 255, 'required': False}), 5: ('wagtail.blocks.ChoiceBlock', [], {'choices': [('show', 'Show'), ('hide', 'Hide')], 'help_text': 'What conditional action would you like to perform on this field?'}), 6: ('wagtail.blocks.CharBlock', (), {'help_text': 'The name of a field in the form', 'max_length': 255, 'required': True}), 7: ('wagtail.blocks.ChoiceBlock', [], {'choices': [('is', 'Is equal to'), ('is_not', 'Is not equal to'), ('greater_than', 'Greater than'), ('greater_than_equal', 'Greater than or equal to'), ('less_than', 'Less than'), ('less_than_equal', 'Less than or equal to'), ('contains', 'Contains'), ('starts-with', 'Starts with'), ('ends-with', 'Ends with')]}), 8: ('wagtail.blocks.CharBlock', (), {'help_text': '', 'max_length': 255, 'required': True}), 9: ('wagtail.blocks.StructBlock', [[('field_name', 6), ('rule', 7), ('value', 8)]], {}), 10: ('wagtail.blocks.ChoiceBlock', [], {'choices': [('is_blank', 'Is blank'), ('is_not_blank', 'Is not blank')]}), 11: ('wagtail.blocks.StructBlock', [[('field_name', 6), ('rule', 10)]], {}), 12: ('wagtail.blocks.StreamBlock', [[('condition', 9), ('blank_condition', 11)]], {'required': False}), 13: ('wagtail.blocks.StructBlock', [[('action', 5), ('conditions', 12)]], {'help_text': 'Add conditional rules to show or hide fields depending on the value of other fields in the form.', 'required': False}), 14: ('wagtail.blocks.StructBlock', [[('label', 0), ('required', 1), ('max_length', 2), ('default_value', 3), ('help_text', 4), ('rules', 13)]], {'label': 'Basic field'}), 15: ('wagtail.blocks.StructBlock', [[('label', 0), ('required', 1), ('max_length', 2), ('default_value', 3), ('help_text', 4), ('rules', 13)]], {'label': 'Email field'}), 16: ('wagtail.blocks.CharBlock', (), {'help_text': 'A unique reference for this html block', 'label': 'Unique reference name', 'max_length': 255, 'required': True}), 17: ('wagtail.blocks.RichTextBlock', (), {'features': ['bold', 'italic', 'h2', 'h3', 'h4', 'h5', 'ol', 'ul', 'link'], 'required': True}), 18: ('wagtail.blocks.StructBlock', [[('label', 16), ('html', 17), ('rules', 13)]], {'label': 'HTML'}), 19: ('wagtail.blocks.TextBlock', (), {'icon': 'extraicons--heading-icon', 'required': True}), 20: ('wagtail.blocks.ListBlock', (19,), {}), 21: ('wagtail.blocks.CharBlock', (), {'max_length': 255, 'required': False}), 22: ('wagtail.blocks.StructBlock', [[('label', 0), ('required', 1), ('choices', 20), ('empty_label', 21), ('default_value', 3), ('help_text', 4), ('rules', 13)]], {'label': 'Dropdown field'}), 23: ('wagtail.blocks.BooleanBlock', (), {'help_text': 'Display these items side by side?', 'required': False}), 24: ('wagtail.blocks.StructBlock', [[('label', 0), ('required', 1), ('choices', 20), ('default_value', 3), ('help_text', 4), ('display_side_by_side', 23), ('rules', 13)]], {'label': 'Radio field'}), 25: ('wagtail.blocks.TextBlock', (), {'help_text': 'Enter a value that matches a checkbox choice above to have it ticked by default.', 'icon': 'extraicons--heading-icon', 'required': False}), 26: ('wagtail.blocks.ListBlock', (25,), {}), 27: ('wagtail.blocks.StructBlock', [[('label', 0), ('required', 1), ('choices', 20), ('default_value', 26), ('help_text', 4), ('display_side_by_side', 23), ('rules', 13)]], {'label': 'Checkboxes field'}), 28: ('wagtail.blocks.BooleanBlock', (), {'default': False, 'help_text': 'Do you want the checkbox label to display? If not you should populate help_text.', 'required': False}), 29: ('wagtail.blocks.StructBlock', [[('label', 0), ('required', 1), ('display_checkbox_label', 28), ('help_text', 21), ('rules', 13)]], {'label': 'Checkbox field'}), 30: ('wagtail.blocks.StructBlock', [[('label', 0), ('required', 1), ('choices', 20), ('default_value', 3), ('help_text', 4), ('rules', 13)]], {'label': 'Multiselect field'}), 31: ('wagtail.blocks.StructBlock', [[('label', 0), ('required', 1), ('default_value', 3), ('help_text', 4), ('rules', 13)]], {'label': 'Multiline field'}), 32: ('wagtail.blocks.StructBlock', [[('label', 0), ('required', 1), ('max_length', 2), ('default_value', 3), ('help_text', 4), ('rules', 13)]], {'label': 'URL field'}), 33: ('wagtail.blocks.CharBlock', (), {'help_text': 'The value to go into the hidden field.', 'label': 'Value', 'max_length': 255, 'required': True}), 34: ('wagtail.blocks.StructBlock', [[('label', 0), ('default_value', 33)]], {'label': 'Hidden field'}), 35: ('wagtail.blocks.StructBlock', [[('label', 0), ('required', 1), ('default_value', 3), ('help_text', 4), ('rules', 13)]], {'label': 'Number field'})}, default=None, help_text='Add fields to the form', null=True),
        ),
    ]
