<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="utf-8">
    <style>
        body {
            font-family: Arial, sans-serif;
            line-height: 1.6;
            color: #333;
        }
        .form-field {
            margin-bottom: 16px;
        }
        .field-label {
            font-weight: bold;
        }
        .field-value {
            margin-top: 4px;
        }
    </style>
    <title>Form submission</title>
</head>
<body>
    <h2>{% if form_title %}{{ form_title }}{% else %}Form Submission{% endif %}</h2>
    {% for field_label, field_value in form_fields %}
        {% if field_value and field_value != 'None' %}
            <div class="form-field">
                <div class="field-label">{{ field_label }}</div>
                <div class="field-value">{{ field_value }}</div>
            </div>
        {% endif %}
    {% endfor %}
</body>
</html>