# Generated by Django 4.2.20 on 2025-05-15 10:47

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('headless_waf_builder', '0006_added_phone_and_simple_date_field'),
    ]

    operations = [
        migrations.AddField(
            model_name='emailformfield',
            name='maximum_age',
            field=models.IntegerField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='emailformfield',
            name='minimum_age',
            field=models.IntegerField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='formfield',
            name='maximum_age',
            field=models.IntegerField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='formfield',
            name='minimum_age',
            field=models.IntegerField(blank=True, default=None, null=True),
        ),
    ]
